"""
#!/usr/bin/env python3
#                            _                _____
#      /\                   | |       /\     |_   _|
#     /  \     ____   __ _  | |_     /  \      | |
#    / /\ \   |_  /  / _` | | __|   / /\ \     | |
#   / ____ \   / /  | (_| | | |_   / ____ \   _| |_
#  /_/    \_\ /___|  \__,_|  \__| /_/    \_\ |_____|
#
#
        # pixel coordinate
        # x1,y1 ------
        # |          |
        # |          |
        # |          |
        # --------x2,y2

        # brick coordinate
        # ----------------------
        # | (a1,b1) |          |
        # |         | (b1,b2)  |
        # ----------------------

        # a is for row
        # b is for column

"""
import os
import glob

import numpy as np
import matplotlib.pyplot as plt
import cv2
import lifebrick
import geoip2.database


def brick2pixel(a1, b1, a2, b2):
    """ converts the given brick coordinates to the pixel coordinates, returns such for value"""

    x1 = b1 * 10
    y1 = a1 * 10
    x2 = b2 * 10 + 10
    y2 = a2 * 10 + 10
    return x1, y1, x2, y2


def pixel2brick(x1, y1, x2, y2):
    """converts given pixel coordinates to the brick coordinate"""

    b1 = x1 // 10
    a1 = y1 // 10
    b2 = (x2 - 10) // 10
    a2 = (y2 - 10) // 10

    return a1, b1, a2, b2


def brick_each(a1, b1, a2, b2):
    """Calculates each brick that selected and returns a list of all envolved bricks"""
    selected = []
    for row in range(a1, a2 + 1):
        for col in range(b1, b2 + 1):
            selected.append((row, col))
    return selected


# brick = brick_each(0, 0, 999, 99)[0]
# roi = brick2pixel(brick[0], brick[1], brick[0], brick[1])
# print(brick)
# print(roi)


def gen_10mil():
    """
    Generates a basic 10 million pixel black image and returns an opencv-python image object. this object can be
    saved using cv2.imwrite method. (should use cv2.imwrite('pixel.png', image, [int(cv2.IMWRITE_PNG_COMPRESSION),
    9]) for compression)
    :param:
    :return: cv2.image object
    """
    height = 10000
    width = 1000
    blank_image = np.zeros((height, width, 3), np.uint8)
    blank_image[:, :] = (200, 200, 200)  # (B, G, R)
    # get pixel value for each 10000 brick
    selected_bricks = brick_each(0, 0, 999, 99)
    print(selected_bricks)
    roi = []
    for brick in selected_bricks:
        roi.append(brick2pixel(brick[0], brick[1], brick[0], brick[1]))
    print(roi)

    color = (26, 127, 239)
    thickness = 1

    for each in roi:
        start_point = (each[0], each[1])
        end_point = (each[2], each[3])
        image = cv2.rectangle(blank_image, start_point, end_point, color, thickness)

    # save the img to the disk
    # if compress is True:
    #     print("compressing....")
    #     cv2.imwrite('pixel.png', image, [int(cv2.IMWRITE_PNG_COMPRESSION), 9])
    # else:
    #     cv2.imwrite('pixel.png', image)
    # return the cv2 image object
    return image


def get_ip_address(request):
    """
    Get client ip address from the django request.
    :param request:
    :return: client_ip
    """
    ip = request.META.get("HTTP_X_FORWARDED_FOR", "")
    if not ip:
        ip = request.META.get('REMOTE_ADDR', "")
    client_ip = ip.split(",")[-1].split() if ip else ""
    return client_ip


def get_country_info(ip_address):
    """
    Get client country using the given ip address.
    :param ip_address:
    :return: country name,iso_code
    """
    # get the city database object
    mmdb = os.path.join(lifebrick.__path__[0], 'data', 'GeoLite2-City.mmdb')
    reader = geoip2.database.Reader(mmdb)
    response = reader.city(ip_address)
    country_name = response.country.name
    country_iso_code = response.country.iso_code
    return country_name, country_iso_code


def draw_visitors(visitor_data={}):
    """
    Draws the visitor data for passed 8 months. should used with schedule and update the data each day.
    :param visitor_data: python dictionary. { '2020-03': 1324, '2020-04':1324 }
    :return: plt object
    :usage:
    plt = draw_visitors()
    plt.show()
    """
    if len(visitor_data) == 0:
        x = ['2020.1', '2020.2', '2020.3', '2020.4', '2020.5', '2020.6', '2020.7', '2020. 8', '2020.9', '2020.10']

        y = [0, 300, 1900, 2500, 3400, 6900, 7000, 500, 1000, 12000]
        for each in x:
            index_ = x.index(each)
            visitor_data[each] = y[index_]

    label = ['visitors']
    fig, ax = plt.subplots()
    ax.stackplot(visitor_data.keys(), visitor_data.values(), labels=label, color='#EE761C')
    ax.legend(loc='upper left')
    return plt


# plt = draw_visitors()
# plt.show()


# _, iso_code = get_country_info('89.218.177.218')
# print(iso_code)


def download_flag(iso_code):
    """
    Downloads the iso flag file to the dir lifebrick/data/flags dir
    :param iso_code:
    :return:
    """
    base_url = "https://www.translatorscafe.com/cafe/images/flags/"
    full_url = base_url + iso_code + '.gif'
    flags_dir = os.path.join(lifebrick.__path__[0], 'data', 'flags')
    full_dir = os.path.join(flags_dir, f"{iso_code}.gif")
    import requests
    import shutil
    # print(full_url)
    # print(full_dir)
    r = requests.get(full_url, stream=True)
    if r.status_code == 200:
        with open(full_dir, 'wb') as f:
            for chunk in r:
                f.write(chunk)


def all_iso_codes():
    """
    Get all iso codes that life brick can handle.
    :return: list file containing all flag iso codes.
    """
    flag_iso = []
    import csv
    csv_dir = os.path.join(lifebrick.__path__[0], 'data', 'iso3166.csv')
    with open(csv_dir, newline='') as csvfile:
        spamreader = csv.reader(csvfile, delimiter='\t')
        for row in spamreader:
            flag_iso.append(row[1])
            flag_iso.append(row[3])
    return flag_iso


# download all the flag images
# from lifebrick.static import flag_iso
#
# for each in flag_iso:
#     download_flag(each)
#     print(each, '0k')


def draw_visitor_country(country_data={}):
    """
    Draws the visitor country data, left side is the country code, x is the total visitors.
    :param country_data: python dictionary. {}
    :return:
    """
    if len(country_data) == 0:
        x = ['US', 'KZ', 'RU', 'TR', 'CN']
        y = [6900, 7000, 500, 1000, 12000]
        for each in x:
            index_ = x.index(each)
            country_data[each] = y[index_]

    fig, ax = plt.subplots()
    countries = country_data.keys()
    visits = country_data.values()
    y_pos = list(countries)
    ax.barh(y_pos, visits, color='#EE761C')
    return plt


def draw_price(price_data={}):
    if len(price_data) == 0:
        price_data = {
            '01.11': {
                'KZT': 2000,
                'USD': 5,
            },
            '02.13': {
                'KZT': 2200,
                'USD': 4,
            },
            '03.21': {
                'KZT': 2500,
                'USD': 3,
            },
            '04.18': {
                'KZT': 2300,
                'USD': 4,
            },
            '05.28': {
                'KZT': 2900,
                'USD': 5.5,
            },
            '06.01': {
                'KZT': 2980,
                'USD': 5.6,
            },
        }

    x_data = list(price_data.keys())
    y_data_kzt = [price_data[each]['KZT'] for each in x_data]
    y_data_usd = [price_data[each]['USD'] for each in x_data]
    plt.figure()

    plt.subplot(121)
    label = 'KZT'
    plt.plot(x_data, y_data_kzt, color='#EE761C', label=label)
    plt.legend(loc='upper left')

    plt.subplot(122)
    label = 'USD'
    plt.plot(x_data, y_data_usd, color='#EE761C', label=label)
    plt.legend(loc='upper left')

    return plt


# plt3 = draw_price()
# plt3.show()



#!/usr/bin/env python3
#                            _                _____
#      /\                   | |       /\     |_   _|
#     /  \     ____   __ _  | |_     /  \      | |
#    / /\ \   |_  /  / _` | | __|   / /\ \     | |
#   / ____ \   / /  | (_| | | |_   / ____ \   _| |_
#  /_/    \_\ /___|  \__,_|  \__| /_/    \_\ |_____|
#
#
"""
This is the static var file.
"""

NATIONS = {'Afghanistan': 'AF',
           'Albania': 'AL',
           'Algeria': 'DZ',
           'American Samoa': 'AS',
           'Andorra': 'AD',
           'Angola': 'AO',
           'Anguilla': 'AI',
           'Antarctica': 'AQ',
           'Antigua and Barbuda': 'AG',
           'Argentina': 'AR',
           'Armenia': 'AM',
           'Aruba': 'AW',
           'Aruba': 'AW',
           'Australia': 'AU',
           'Austria': 'AT',
           'Azerbaijan': 'AZ',
           'Bahamas': 'BS',
           'Bahrain': 'BH',
           'Bangladesh': 'BD',
           'Barbados': 'BB',
           'Belarus': 'BY',
           'Belgium': 'BE',
           'Belize': 'BZ',
           'Benin': 'BJ',
           'Bermuda': 'BM',
           'Bhutan': 'BT',
           'Bolivia, Plurinational State of': 'BO',
           'Bonaire, Sint Eustatius and Saba': 'BQ',
           'Bosnia and Herzegovina': 'BA',
           'Botswana': 'BW',
           'Bouvet Island': 'BV',
           'Brazil': 'BR',
           'British Indian Ocean Territory': 'IO',
           'Brunei Darussalam': 'BN',
           'Bulgaria': 'BG',
           'Burkina Faso': 'BF',
           'Burundi': 'BI',
           'Cambodia': 'KH',
           'Cameroon': 'CM',
           'Canada': 'CA',
           'Cape Verde': 'CV',
           'Cayman Islands': 'KY',
           'Central African Republic': 'CF',
           'Chad': 'TD',
           'Chile': 'CL',
           'China': 'CN',
           'Christmas Island': 'CX',
           'Cocos (Keeling) Islands': 'CC',
           'Colombia': 'CO',
           'Comoros': 'KM',
           'Congo': 'CG',
           'Congo, the Democratic Republic of the': 'CD',
           'Cook Islands': 'CK',
           'Costa Rica': 'CR',
           'Country name': 'Code',
           'Croatia': 'HR',
           'Cuba': 'CU',
           'Curaçao': 'CW',
           'Cyprus': 'CY',
           'Czech Republic': 'CZ',
           "Côte d'Ivoire": 'CI',
           'Denmark': 'DK',
           'Djibouti': 'DJ',
           'Dominica': 'DM',
           'Dominican Republic': 'DO',
           'Ecuador': 'EC',
           'Egypt': 'EG',
           'El Salvador': 'SV',
           'Equatorial Guinea': 'GQ',
           'Eritrea': 'ER',
           'Estonia': 'EE',
           'Ethiopia': 'ET',
           'Falkland Islands (Malvinas)': 'FK',
           'Faroe Islands': 'FO',
           'Fiji': 'FJ',
           'Finland': 'FI',
           'France': 'FR',
           'French Guiana': 'GF',
           'French Polynesia': 'PF',
           'French Southern Territories': 'TF',
           'Gabon': 'GA',
           'Gambia': 'GM',
           'Georgia': 'GE',
           'Germany': 'DE',
           'Ghana': 'GH',
           'Gibraltar': 'GI',
           'Greece': 'GR',
           'Greenland': 'GL',
           'Grenada': 'GD',
           'Guadeloupe': 'GP',
           'Guam': 'GU',
           'Guatemala': 'GT',
           'Guernsey': 'GG',
           'Guinea': 'GN',
           'Guinea-Bissau': 'GW',
           'Guyana': 'GY',
           'Haiti': 'HT',
           'Heard Island and McDonald Islands': 'HM',
           'Holy See (Vatican City State)': 'VA',
           'Honduras': 'HN',
           'Hong Kong': 'HK',
           'Hungary': 'HU',
           'ISO 3166-2:GB': '(.uk)',
           'Iceland': 'IS',
           'India': 'IN',
           'Indonesia': 'ID',
           'Iran, Islamic Republic of': 'IR',
           'Iraq': 'IQ',
           'Ireland': 'IE',
           'Isle of Man': 'IM',
           'Israel': 'IL',
           'Italy': 'IT',
           'Jamaica': 'JM',
           'Japan': 'JP',
           'Jersey': 'JE',
           'Jordan': 'JO',
           'Kazakhstan': 'KZ',
           'Kenya': 'KE',
           'Kiribati': 'KI',
           "Korea, Democratic People's Republic of": 'KP',
           'Korea, Republic of': 'KR',
           'Kuwait': 'KW',
           'Kyrgyzstan': 'KG',
           "Lao People's Democratic Republic": 'LA',
           'Latvia': 'LV',
           'Lebanon': 'LB',
           'Lesotho': 'LS',
           'Liberia': 'LR',
           'Libya': 'LY',
           'Liechtenstein': 'LI',
           'Lithuania': 'LT',
           'Luxembourg': 'LU',
           'Macao': 'MO',
           'Macedonia, the former Yugoslav Republic of': 'MK',
           'Madagascar': 'MG',
           'Malawi': 'MW',
           'Malaysia': 'MY',
           'Maldives': 'MV',
           'Mali': 'ML',
           'Malta': 'MT',
           'Marshall Islands': 'MH',
           'Martinique': 'MQ',
           'Mauritania': 'MR',
           'Mauritius': 'MU',
           'Mayotte': 'YT',
           'Mexico': 'MX',
           'Micronesia, Federated States of': 'FM',
           'Moldova, Republic of': 'MD',
           'Monaco': 'MC',
           'Mongolia': 'MN',
           'Montenegro': 'ME',
           'Montserrat': 'MS',
           'Morocco': 'MA',
           'Mozambique': 'MZ',
           'Myanmar': 'MM',
           'Namibia': 'NA',
           'Nauru': 'NR',
           'Nepal': 'NP',
           'Netherlands': 'NL',
           'New Caledonia': 'NC',
           'New Zealand': 'NZ',
           'Nicaragua': 'NI',
           'Niger': 'NE',
           'Nigeria': 'NG',
           'Niue': 'NU',
           'Norfolk Island': 'NF',
           'Northern Mariana Islands': 'MP',
           'Norway': 'NO',
           'Oman': 'OM',
           'Pakistan': 'PK',
           'Palau': 'PW',
           'Palestine, State of': 'PS',
           'Panama': 'PA',
           'Papua New Guinea': 'PG',
           'Paraguay': 'PY',
           'Peru': 'PE',
           'Philippines': 'PH',
           'Pitcairn': 'PN',
           'Poland': 'PL',
           'Portugal': 'PT',
           'Puerto Rico': 'PR',
           'Qatar': 'QA',
           'Romania': 'RO',
           'Russian Federation': 'RU',
           'Rwanda': 'RW',
           'Réunion': 'RE',
           'Saint Barthélemy': 'BL',
           'Saint Helena, Ascension and Tristan da Cunha': 'SH',
           'Saint Kitts and Nevis': 'KN',
           'Saint Lucia': 'LC',
           'Saint Martin (French part)': 'MF',
           'Saint Pierre and Miquelon': 'PM',
           'Saint Vincent and the Grenadines': 'VC',
           'Samoa': 'WS',
           'San Marino': 'SM',
           'Sao Tome and Principe': 'ST',
           'Saudi Arabia': 'SA',
           'Senegal': 'SN',
           'Serbia': 'RS',
           'Seychelles': 'SC',
           'Sierra Leone': 'SL',
           'Singapore': 'SG',
           'Sint Maarten (Dutch part)': 'SX',
           'Slovakia': 'SK',
           'Slovenia': 'SI',
           'Solomon Islands': 'SB',
           'Somalia': 'SO',
           'South Africa': 'ZA',
           'South Georgia and the South Sandwich Islands': 'GS',
           'South Sudan': 'SS',
           'Spain': 'ES',
           'Sri Lanka': 'LK',
           'Sudan': 'SD',
           'Suriname': 'SR',
           'Svalbard and Jan Mayen': 'SJ',
           'Swaziland': 'SZ',
           'Sweden': 'SE',
           'Switzerland': 'CH',
           'Syrian Arab Republic': 'SY',
           'Taiwan, Province of China': 'TW',
           'Tajikistan': 'TJ',
           'Tanzania, United Republic of': 'TZ',
           'Thailand': 'TH',
           'Timor-Leste': 'TL',
           'Togo': 'TG',
           'Tokelau': 'TK',
           'Tonga': 'TO',
           'Trinidad and Tobago': 'TT',
           'Tunisia': 'TN',
           'Turkey': 'TR',
           'Turkmenistan': 'TM',
           'Turks and Caicos Islands': 'TC',
           'Tuvalu': 'TV',
           'Uganda': 'UG',
           'Ukraine': 'UA',
           'United Arab Emirates': 'AE',
           'United Kingdom': 'GB',
           'United States': 'US',
           'United States Minor Outlying Islands': 'UM',
           'Uruguay': 'UY',
           'Uzbekistan': 'UZ',
           'Vanuatu': 'VU',
           'Venezuela, Bolivarian Republic of': 'VE',
           'Viet Nam': 'VN',
           'Virgin Islands, British': 'VG',
           'Virgin Islands, U.S.': 'VI',
           'Wallis and Futuna': 'WF',
           'Western Sahara': 'EH',
           'Yemen': 'YE',
           'Zambia': 'ZM',
           'Zimbabwe': 'ZW',
           'Åland Islands': 'AX'
           }

flag_iso = (
    'AF', 'AL', 'DZ', 'AD', 'AO', 'AG', 'AR', 'AM', 'AU', 'AT', 'AZ', 'BS', 'BH', 'BD', 'BB', 'BY', 'BE', 'BZ', 'BJ',
    'BT',
    'BO', 'BA', 'BW', 'BR', 'BN', 'BG', 'BF', 'BI', 'KH', 'CM', 'CA', 'CV', 'CF', 'TD', 'CL', 'CN', 'CO', 'KM', 'CD',
    'CR',
    'CI', 'HR', 'CU', 'CY', 'CZ', 'DK', 'DJ', 'DM', 'DO', 'TL', 'EC', 'EG', 'SV', 'GQ', 'ER', 'EE', 'ET', 'FJ', 'FI',
    'FR',
    'PF', 'GA', 'GM', 'GE', 'DE', 'GH', 'GI', 'GR', 'GL', 'GD', 'GP', 'GT', 'GN', 'GW', 'GY', 'HT', 'HN', 'HK', 'HU',
    'IS',
    'IN', 'ID', 'IR', 'IQ', 'IE', 'IL', 'IT', 'JM', 'JP', 'JO', 'KZ', 'KE', 'KI', 'KP', 'KR', 'KW', 'KG', 'LA', 'LV',
    'LB',
    'LS', 'LR', 'LY', 'LI', 'LT', 'LU', 'MO', 'MK', 'MG', 'MW', 'MY', 'MV', 'ML', 'MT', 'MH', 'MQ', 'MR', 'MU', 'MX',
    'FM',
    'MD', 'MC', 'MN', 'ME', 'MA', 'MZ', 'MM', 'NA', 'NR', 'NP', 'NL', 'NC', 'NZ', 'NI', 'NE', 'NG', 'MP', 'NO', 'OM',
    'PK',
    'PW', 'PS', 'PA', 'PG', 'PY', 'PE', 'PH', 'PL', 'PT', 'PR', 'QA', 'RE', 'RO', 'RU', 'RW', 'KN', 'LC', 'WS', 'SM',
    'ST',
    'SA', 'SN', 'RS', 'SC', 'SL', 'SG', 'SK', 'SI', 'SB', 'SO', 'ZA', 'ES', 'LK', 'VC', 'SD', 'SR', 'SZ', 'SE', 'CH',
    'SY',
    'TW', 'TJ', 'TZ', 'TH', 'TG', 'TO', 'TT', 'TN', 'TR', 'TM', 'TV', 'UG', 'UA', 'AE', 'GB', 'US', 'UY', 'UZ', 'VU',
    'VA',
    'VE', 'VN', 'VG', 'VI', 'EH', 'YE', 'ZM', 'ZW')



#!/usr/bin/env python3
#                            _                _____
#      /\                   | |       /\     |_   _|
#     /  \     ____   __ _  | |_     /  \      | |
#    / /\ \   |_  /  / _` | | __|   / /\ \     | |
#   / ____ \   / /  | (_| | | |_   / ____ \   _| |_
#  /_/    \_\ /___|  \__,_|  \__| /_/    \_\ |_____|
#
#

import os
import sys
import glob

from codecs import open

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

# 'setup.py publish' shortcut.
if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist')
    os.system('twine upload dist/*')
    os.system('rm -rf dist')
    os.system('rm -rf *.egg-info')
    sys.exit()

requires = [
    # Add predefined packages here.
    'click',
    'geoip2',
    'opencv-python',
    'numpy',
    'matplotlib',
    'schedule',
    'iso3166'
]

about = {}  # create a empty dictionary to store the content of the __version__.py file
# execute the __version__.py file and get the content, save to the dictionary about.
with open(os.path.join(here, 'lifebrick', '__version__.py'), 'r', 'utf-8') as f:
    exec(f.read(), about)

with open('README.md', 'r', 'utf-8') as f:
    readme = f.read()

setup(
    name=about['__title__'],
    version=about['__version__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=find_packages(),
    package_data={
        # include the mmdb database file within the lifebrick package.
        "lifebrick": ['data/*.mmdb', 'data/flags/*.png', 'data/flags/*.svg'],
        # have to add the country flags database (png images)
    },
    include_package_data=True,
    python_requires=">=3.5",
    install_requires=requires,
    entry_points='''
        [console_scripts]
        startpkg=src.cli:cli
    ''',
    license=about['__license__'],
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    project_urls={
        'Documentation': 'https://azat.ai',
        'Source': 'https://github.com/AzatAI/lifebrick',
    },
)
